@@ -16,14 +16,14 @@ from twitchdl.exceptions import ConsoleError
 from twitchdl.output import print_out, print_video
 
 
-def videos(channel_name, limit, offset, sort, **kwargs):
+def videos(channel_name, limit, offset, sort, type, **kwargs):
     print_out("Looking up user...")
     user = twitch.get_user(channel_name)
     if not user:
         raise ConsoleError("User {} not found.".format(channel_name))
 
     print_out("Loading videos...")
-    videos = twitch.get_channel_videos(user["id"], limit, offset, sort)
+    videos = twitch.get_channel_videos(user["id"], limit, offset, sort, type)
     count = len(videos['videos'])
     if not count:
         print_out("No videos found")
@@ -134,7 +134,7 @@ def download(video, **kwargs):
             video_id = match.group('id')
             return _download_video(video_id, **kwargs)
 
-    raise ConsoleError("Invalid video: {}".format(video_id))
+    raise ConsoleError("Invalid video: {}".format(video))
 
 
 def _download_clip(slug, **kwargs):
