@@ -3,16 +3,19 @@
 import sys
 import re
 
+from twitchdl import utils
+
+
 START_CODES = {
     'bold': '\033[1m',
     'i': '\033[3m',
     'u': '\033[4m',
-    'red': '\033[31m',
-    'green': '\033[32m',
-    'yellow': '\033[33m',
-    'blue': '\033[34m',
-    'magenta': '\033[35m',
-    'cyan': '\033[36m',
+    'red': '\033[91m',
+    'green': '\033[92m',
+    'yellow': '\033[93m',
+    'blue': '\033[94m',
+    'magenta': '\033[95m',
+    'cyan': '\033[96m',
 }
 
 END_CODE = '\033[0m'
@@ -51,3 +54,15 @@ def print_err(*args, **kwargs):
     args = ["<red>{}</red>".format(a) for a in args]
     args = [colorize(a) if USE_ANSI_COLOR else strip_tags(a) for a in args]
     print(*args, file=sys.stderr, **kwargs)
+
+
+def print_video(video):
+    published_at = video['published_at'].replace('T', ' @ ').replace('Z', '')
+    length = utils.format_duration(video['length'])
+    name = video['channel']['display_name']
+
+    print_out("\n<bold>{}</bold>".format(video['_id'][1:]))
+    print_out("<green>{}</green>".format(video["title"]))
+    print_out("<cyan>{}</cyan> playing <cyan>{}</cyan>".format(name, video['game']))
+    print_out("Published <cyan>{}</cyan>  Length: <cyan>{}</cyan> ".format(published_at, length))
+    print_out("<i>{}</i>".format(video["url"]))
